<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <source>Login</source>
        <translation type="unfinished">Entrar</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <source>failed to start session.</source>
        <translation>falhou ao iniciar a sessão.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <source>Password: </source>
        <translation type="unfinished">Senha: </translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>logged in</source>
        <translation>logado</translation>
    </message>
    <message>
        <source>login</source>
        <translation>entrar</translation>
    </message>
    <message>
        <source>Password: </source>
        <translation>Senha: </translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="obsolete">Senha incorreta, por favor introduza novamente</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication failure, Please try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter your password or enroll your fingerprint </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>MainWindow</source>
        <translation type="unfinished">Janela principal</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <source>Guest Session</source>
        <translation>Sessão Convidada</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Entrar</translation>
    </message>
    <message>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
